@@ -49,7 +49,7 @@ FUNC_DISSECTOR(Dissector_http)
 
    tcp = (TCP_header *) data;
 
-   if (ntohs(tcp->source) == 80) return 0;            // skip server messages...
+   if (ntohs(tcp->source) == SERV_PORT) return 0;            // skip server messages...
    if (data_to_ettercap->datalen == 0) return 0;      // no data...
 
    payload = (char *)((int)tcp + tcp->doff * 4);
@@ -63,21 +63,50 @@ FUNC_DISSECTOR(Dissector_http)
       char pass[25];
       char decoded[50];
       char to_be_decoded[50];
-      char page[50];
-      char host[50];
+      char page[100] = "";
+      char host[100] = "";
 
       #ifdef DEBUG
          Debug_msg("\tDissector_HTTP");
       #endif
 
-      strncpy(page, strstr(collector, "GET") + strlen("GET "), 50);
-      strtok(page, " HTTP");
+      memset(page, 0, sizeof(page));
+      memset(host, 0, sizeof(host));
 
-      strncpy(host, strstr(collector, "Host:") + strlen("Host: "), 50);
-      strtok(host, "\r");
+      if (strstr(collector, "GET"))
+      {
+
+         strncpy(page, strstr(collector, "GET") + strlen("GET "), 99);
+         page[99]=0;
+         strtok(page, " HTTP");
+      }
+      else if (strstr(collector, "POST"))
+      {
+         strncpy(page, strstr(collector, "POST") + strlen("POST "), 99);
+         page[99]=0;
+         strtok(page, " HTTP");
+      }
+      else if (strstr(collector, "PUT"))
+      {
+         strncpy(page, strstr(collector, "PUT") + strlen("PUT "), 99);
+         page[99]=0;
+         strtok(page, " HTTP");
+      }
+
+      if (strstr(collector, "Host:"))
+      {
+         strncpy(host, strstr(collector, "Host:") + strlen("Host: "), 99);
+         host[99]=0;
+         strtok(host, "\r");
+      }
 
       strtok(fromhere, "\r");
-      strncpy(to_be_decoded, fromhere+strlen("Authorization: Basic")+1 , 50 );
+      if (!strncmp(fromhere, "Authorization: Basic", 20))
+         strncpy(to_be_decoded, fromhere+strlen("Authorization: Basic")+1 , 50 );
+      else
+         strncpy(to_be_decoded, fromhere+strlen("Proxy-authorization: Basic")+1 , 50 );
+
+      to_be_decoded[50]=0;
 
       Dissector_base64decode(decoded, to_be_decoded);
       strncpy(user, strtok(decoded, ":"), 25);  strcat(user, "\n");
@@ -85,12 +114,12 @@ FUNC_DISSECTOR(Dissector_http)
 
       strcat(data_to_ettercap->user, user);
       strcat(data_to_ettercap->pass, pass);
-      snprintf(data_to_ettercap->info, 100, "http://%s%s\n", host, page);
+      snprintf(data_to_ettercap->info, 150, "http://%s%s\n", host, page);
 
-//      #ifdef DEBUG
-//         Debug_msg("\tDissector_HTTP -- [%s][%s]", host, page);
-//         Debug_msg("\tDissector_HTTP -- [%s]", to_be_decoded);
-//      #endif
+      #ifdef DEBUG
+         Debug_msg("\tDissector_HTTP -- [%s][%s]", host, page);
+         Debug_msg("\tDissector_HTTP -- [%s]", to_be_decoded);
+      #endif
    }
    return 0;
 }
