@@ -49,7 +49,7 @@ FUNC_DISSECTOR(Dissector_imap)
 
    tcp = (TCP_header *) data;
 
-   if (ntohs(tcp->source) == 143 || ntohs(tcp->source) == 220) return 0;           // skip server messages...
+   if (ntohs(tcp->source) == SERV_PORT) return 0;           // skip server messages...
 
    payload = (char *)((int)tcp + tcp->doff * 4);
 
