@@ -50,6 +50,7 @@ FUNC_DISSECTOR(Dissector_irc)
 
    tcp = (TCP_header *) data;
 
+	if (ntohs(tcp->source) == SERV_PORT) return 0;      // skip server messages...
    if (data_to_ettercap->datalen == 0) return 0;       // no data...
 
    payload = (char *)((int)tcp + tcp->doff * 4);
@@ -89,8 +90,10 @@ FUNC_DISSECTOR(Dissector_irc)
    {
       int i, count = 0;
 
+		strtok(collector, "\r");
+
       for (i=0; i <= strlen(collector); i++) // if count == 2 there is the channel key !
-         if (collector[i] == ' ') count++;
+         if (collector[i] == ' ' && collector[i+1] != 0) count++;
 
       if (count == 2)
       {
