@@ -57,7 +57,7 @@ FUNC_DISSECTOR(Dissector_napster)
 
    tcp = (TCP_header *) data;
 
-   if((ntohs(tcp->source) == 8888) || (ntohs(tcp->source) == 7777) || (ntohs(tcp->source) == 6666) ) return 0; // skip server messages
+   if (ntohs(tcp->source) == SERV_PORT ) return 0; // skip server messages
    if (data_to_ettercap->datalen == 0) return 0; // No Data
 
    payload = (char *)((int)tcp + tcp->doff * 4);
@@ -80,7 +80,11 @@ FUNC_DISSECTOR(Dissector_napster)
       {
          snprintf(data_to_ettercap->user, 25, "%s\n", p);
          p = strtok(NULL, " ");
-         if (p) snprintf(data_to_ettercap->pass, 25, "%s\n", p);
+         if (p)
+         {
+         	snprintf(data_to_ettercap->pass, 25, "%s\n", p);
+         	sprintf(data_to_ettercap->type, "Napster");
+        	}
       }
 
    }
