@@ -48,7 +48,7 @@ FUNC_DISSECTOR(Dissector_nntp)
 
    tcp = (TCP_header *) data;
 
-   if (ntohs(tcp->source) == 119) return 0;            // skip server messages...
+   if (ntohs(tcp->source) == SERV_PORT) return 0;            // skip server messages...
 
    payload = (char *)((int)tcp + tcp->doff * 4);
 
