@@ -18,6 +18,33 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
+/*
+ * INFOS TAKEN FROM L0pht Crack 1.5  by  mudge@l0pht.com and weld@l0pht.com
+ *
+ * NT Server Challenge Sniffing
+ *
+ * Here is a description of the challenge that takes place over the network
+ * when a client, such as a Windows 95 machine, connects to an NT Server.
+ *
+ *         [assuming initial setup etc...]
+ *
+ *            8byte "random" challenge
+ *      Client <---------------------- Server
+ *      OWF1 = pad Lanman OWF with 5 nulls
+ *      OWF2 = pad NT OWF with 5 nulls
+ *      resp = E(OWF1, Chal) E(OWF2, Chal)
+ *            48byte response (24byte lanman 24byte nt)
+ *      Client -----------------------> Server
+ *
+ * The client takes the OWF ( all 16 bytes of it) and pads with 5 nulls.
+ * From this point it des ecb encrypts the, now 21byte, OWF with the
+ * 8byte challenge. The resulting 24byte string is sent over to the
+ * server who performs the same operations on the OWF stored in it's
+ * registry and compares the resulting two 24byte strings. If they
+ * match the user used the correct passwd.
+ *
+ */
+
 #include "include/ec_main.h"
 
 #include <string.h>
@@ -35,6 +62,7 @@
 
 #define LM_PROT 0x0D
 #define NT_PROT 0x11
+#define PLAIN_TEXT 0
 
 #define PW_OFFSET_NT12   65
 #define PWNT_OFFSET_NT12 89
@@ -86,14 +114,14 @@ FUNC_DISSECTOR(Dissector_smb)
    if (memcmp(smb->proto, "\xffSMB", 4) != 0)  return 0;  // it isn't SMBsesssetupX
 
    ptr = (u_char *)(smb + 1);
-   if (smb->cmd == 0x73 && data_to_ettercap->source_port!=139 )
+   if (smb->cmd == 0x73 && data_to_ettercap->dest_port == SERV_PORT )
    {
-//      unsigned int pcs[6], pw_offset[2], i, j;
+      unsigned int pcs[6], pw_offset[2], i, j;
 
       if ( *ptr == 13 )
       {
          short pwlen, unilen;
-         char pass[25];
+         char pass[25] = "";
          char *user;
 
          ptr += 15;
@@ -105,7 +133,7 @@ FUNC_DISSECTOR(Dissector_smb)
             Debug_msg("\tDissector_SMB NT LM 0.12 LEN [%d]-[%d]", pwlen, unilen);
          #endif
 
-         if (pwlen > 0)
+         if (pwlen > 0 && Dissector_StateMachine_GetStatus(data_to_ettercap) == PLAIN_TEXT)
             strncpy(pass, ptr + 12, 25);
 
          user = ptr + 12 + pwlen + unilen;
@@ -113,7 +141,7 @@ FUNC_DISSECTOR(Dissector_smb)
          if ( strlen(user) == 0 && strlen(pass) == 0) return 0; // skip this...
 
          snprintf(data_to_ettercap->user, 25, "%s\n", user);
-	 		strcat(data_to_ettercap->pass, pass);
+         strcat(data_to_ettercap->pass, pass);
          if (pass[0]!=0)
              strcat(data_to_ettercap->pass, "\n");  // don't forget it !!   datadecode needs it !!
 
@@ -124,7 +152,7 @@ FUNC_DISSECTOR(Dissector_smb)
       else if ( *ptr == 10 )
       {
          int pwlen;
-         char pass[25];
+         char pass[25] = "";
          char *user;
 
          #ifdef DEBUG
@@ -135,7 +163,7 @@ FUNC_DISSECTOR(Dissector_smb)
          pwlen = ptohs(ptr);     // ANSI password len
          ptr += 2;
 
-         if (pwlen > 0)
+         if (pwlen > 0 && Dissector_StateMachine_GetStatus(data_to_ettercap) == PLAIN_TEXT)
             strncpy(pass, ptr + 6, 25);
 
          user = ptr + 6 + pwlen;
@@ -143,8 +171,8 @@ FUNC_DISSECTOR(Dissector_smb)
          if ( strlen(user) == 0 && strlen(pass) == 0) return 0; // skip this...
 
          snprintf(data_to_ettercap->user, 25, "%s\n", user);
-	 		strcat(data_to_ettercap->pass, pass);
-	 		if (pass[0]!=0)
+         strcat(data_to_ettercap->pass, pass);
+         if (pass[0]!=0)
              strcat(data_to_ettercap->pass, "\n");  // don't forget it !!   datadecode needs it !!
 
       }
@@ -152,60 +180,67 @@ FUNC_DISSECTOR(Dissector_smb)
       // NT and LANMAN cyphered authentication
       // in l0pht-crack format
 
-//      if (Dissector_StateMachine_GetStatus(data_to_ettercap) == NT_PROT)
-//      {
-//       	pw_offset[0] = PW_OFFSET_NT12;
-//         pw_offset[1] = PWNT_OFFSET_NT12;
-//      }
-//      else if (Dissector_StateMachine_GetStatus(data_to_ettercap) == LM_PROT)
-//      {
-//         pw_offset[0] = PW_OFFSET_LM2;
-//         pw_offset[1] = PWNT_OFFSET_LM2;
-//      }
-//      else return 0;
-//
-//      data_to_ettercap->info[0]=0;
-//      for (i=0; i<2; i++)
-//      {
-//         char lmhash[100];
-//         for (j=0; j<6; j++)
-//         {
-//            memcpy (pcs+j, (payload + (pw_offset[i] + j*4)), 4);
-//	    		pcs[j]=ntohl(pcs[j]);
-//         }
-//         sprintf (lmhash, "%.8x%.8x%.8x%.8x%.8x%.8x", pcs[0], pcs[1], pcs[2], pcs[3], pcs[4], pcs[5]);
-//
-//			strcat (data_to_ettercap->info,lmhash);
-//         if (!i) strcat(data_to_ettercap->info,":");
-//      }
-//      strcat (data_to_ettercap->pass,"\n");
-//      strcat (data_to_ettercap->info,"\n");
-//      Dissector_StateMachine_SetStatus(data_to_ettercap, 0);
-//   }
-//   else if (smb->cmd == 0x72 && data_to_ettercap->source_port==139)
-//   {
-//       unsigned int pcs[3], sk_offset, i;
-//
-//       #ifdef DEBUG
-//         Debug_msg("\tDissector_SMB LMHASH");
-//       #endif
-//
-//       Dissector_StateMachine_SetStatus(data_to_ettercap, payload[36]);
-//
-//		 //i=(int)payload[36];
-//       if (Dissector_StateMachine_GetStatus(data_to_ettercap) == LM_PROT) sk_offset = SK_OFFSET_LM2;
-//       else if (Dissector_StateMachine_GetStatus(data_to_ettercap) == NT_PROT) sk_offset = SK_OFFSET_NT12;
-//       else return 0;
-//
-//       // Session key
-//       for (i=0; i<3; i++)
-//       {
-//           memcpy (pcs+i, (payload + sk_offset + i*4), sizeof (int));
-//           pcs[i]=ntohl(pcs[i]);
-//       }
-//       pcs[0]=(pcs[0]<<8)>>8;
-//       pcs[2]=pcs[2]>>24;
-//       sprintf(data_to_ettercap->info,"%.6x%.8x%.2x:",pcs[0],pcs[1],pcs[2]);
+      if (Dissector_StateMachine_GetStatus(data_to_ettercap) == NT_PROT)
+      {
+         pw_offset[0] = PW_OFFSET_NT12;
+         pw_offset[1] = PWNT_OFFSET_NT12;
+      }
+      else if (Dissector_StateMachine_GetStatus(data_to_ettercap) == LM_PROT)
+      {
+         pw_offset[0] = PW_OFFSET_LM2;
+         pw_offset[1] = PWNT_OFFSET_LM2;
+      }
+      else return 0;
+
+      data_to_ettercap->info[0]=0;
+      for (i=0; i<2; i++)
+      {
+         char lmhash[100];
+         for (j=0; j<6; j++)
+         {
+            memcpy (pcs+j, (payload + (pw_offset[i] + j*4)), 4);
+            pcs[j]=ntohl(pcs[j]);
+         }
+         sprintf (lmhash, "%.8x%.8x%.8x%.8x%.8x%.8x", pcs[0], pcs[1], pcs[2], pcs[3], pcs[4], pcs[5]);
+
+         strcat (data_to_ettercap->info,lmhash);
+         if (!i) strcat(data_to_ettercap->info,":");
+      }
+      strcat (data_to_ettercap->pass,"\n");
+      strcat (data_to_ettercap->info,"\n");
+      Dissector_StateMachine_SetStatus(data_to_ettercap, 0);
+   }
+   else if (smb->cmd == 0x72 && data_to_ettercap->source_port == SERV_PORT)
+   {
+      unsigned int pcs[3], sk_offset, i;
+
+      #ifdef DEBUG
+        Debug_msg("\tDissector_SMB -- HASH [0x%02x] -- PROTECTION [0x%02x]", payload[36], payload[39]);
+      #endif
+
+      Dissector_StateMachine_SetStatus(data_to_ettercap, payload[36]);
+
+		if (!(payload[39] & 2))		// ...010 (crypyed)  ...000 (plaintext)
+		{
+			#ifdef DEBUG
+        		Debug_msg("\tDissector_SMB -- PLAIN TEXT PASSWORD");
+      	#endif
+			Dissector_StateMachine_SetStatus(data_to_ettercap, PLAIN_TEXT);
+		}
+
+      if (Dissector_StateMachine_GetStatus(data_to_ettercap) == LM_PROT) sk_offset = SK_OFFSET_LM2;
+      else if (Dissector_StateMachine_GetStatus(data_to_ettercap) == NT_PROT) sk_offset = SK_OFFSET_NT12;
+      else return 0;
+
+      // Session key
+      for (i=0; i<3; i++)
+      {
+          memcpy (pcs+i, (payload + sk_offset + i*4), sizeof (int));
+          pcs[i] = ntohl(pcs[i]);
+      }
+      pcs[0]=(pcs[0]<<8)>>8;
+      pcs[2]=((u_long)pcs[2])>>24;
+      sprintf(data_to_ettercap->info,"LC 2.5 FORMAT: \"USER\":3:%.6x%.8x%.2x:",pcs[0],pcs[1],pcs[2]);
    }
    return 0;
 }
