@@ -52,7 +52,7 @@ FUNC_DISSECTOR(Dissector_socks)
 
    if (*payload != 5 ) return 0;    // not the right version (5)
 
-   if ((data_to_ettercap->datalen == 2) && !memcmp(payload, "\x05\x02", 2))   // server accepted user/password method
+   if ((data_to_ettercap->datalen == 2) && !memcmp(payload, "\x05\x02", 2) && ntohs(tcp->source) == SERV_PORT)   // server accepted user/password method
    {
       #ifdef DEBUG
          Debug_msg("\tDissector_SOCKS 5 -- auth user/pass");
@@ -61,7 +61,7 @@ FUNC_DISSECTOR(Dissector_socks)
       return 0;
    }
 
-   if (Dissector_StateMachine_GetStatus(data_to_ettercap) == 1)
+   if (Dissector_StateMachine_GetStatus(data_to_ettercap) == 1 && ntohs(tcp->dest) == SERV_PORT)
    {
       len = *++payload;
       if (len>23) len = 23;		// adapted to fit in our buffer...
