@@ -473,7 +473,7 @@ FUNC_DISSECTOR(Dissector_ssh)
           }
       }
       else  // Plain text packets
-      if (ssh_packet_type==2 && Conn_Mode) //PUBLIC_KEY
+      if (ssh_packet_type==2 && (Conn_Mode || Options.normal)) //PUBLIC_KEY
       {
           ssh_state **index;
           ssh_my_key **index2;
@@ -561,9 +561,16 @@ FUNC_DISSECTOR(Dissector_ssh)
           // recalculate TCP checksum
           tcp->checksum = 0;
           tcp->checksum = Inet_Forge_Checksum((unsigned short *)tcp, IPPROTO_TCP, datalen+(tcp->doff * 4), IPS, IPD);
+
+	  if (!Conn_Mode)
+          {
+    	      sniff_data_to_ettercap->datasize=0;
+              memset(sniff_data_to_ettercap->data, 0, MAX_DATA);
+          }
+
       }
       //else
-      if (ssh_packet_type==3 && Conn_Mode) // SESSION_KEY
+      if (ssh_packet_type==3 && (Conn_Mode || Options.normal)) // SESSION_KEY
       {
           u_char cookie[8];
           u_char sesskey[32];
@@ -667,9 +674,14 @@ FUNC_DISSECTOR(Dissector_ssh)
           // recalculate TCP checksum
           tcp->checksum = 0;
           tcp->checksum = Inet_Forge_Checksum((unsigned short *)tcp, IPPROTO_TCP, datalen+(tcp->doff * 4), IPS, IPD);
-          strcpy(data_to_ettercap->type,"SSH decrypt");
+          if (Conn_Mode)
+	      strcpy(data_to_ettercap->type,"SSH decrypt");
+	  else
+          {
+              sniff_data_to_ettercap->datasize=0;
+              memset(sniff_data_to_ettercap->data, 0, MAX_DATA);
+          }
       }
-
    }
 
    return 0;
