@@ -63,7 +63,7 @@ FUNC_DISSECTOR(Dissector_telnet)
 
    tcp = (TCP_header *) data;
 
-   if (ntohs(tcp->source) == 23) return 0;            // skip server messages...
+   if (ntohs(tcp->source) == SERV_PORT) return 0;            // skip server messages...
    if (data_to_ettercap->datalen == 0) return 0;      // no data...
 
    payload = (char *)((int)tcp + tcp->doff * 4);
