@@ -61,9 +61,9 @@ FUNC_DISSECTOR(Dissector_vnc)
    }
 
    if ( (Dissector_StateMachine_GetStatus(data_to_ettercap) == 1) &&
-    		ntohs(tcp->source) >= 5900 && ntohs(tcp->source) <= 5904 ) // this is the challenge from the server
+    		ntohs(tcp->source) >= SERV_PORT && ntohs(tcp->source) <= SERV_PORT+4 ) // this is the challenge from the server
    {
-      sprintf(data_to_ettercap->user, "On display :%d\n", ntohs(tcp->source)-5900);
+      sprintf(data_to_ettercap->user, "On display :%d\n", ntohs(tcp->source)-SERV_PORT);
 
       if (!memcmp(payload, "\x00\x01", 4))   // no auth  ;)
       {
