@@ -59,8 +59,8 @@ FUNC_DISSECTOR(Dissector_x11)
       #ifdef DEBUG
          Debug_msg("\tDissector_X11");
       #endif
-      if (ntohs(tcp->dest) >= 6000 && ntohs(tcp->dest) <= 6004)
-         sprintf(data_to_ettercap->user, "On display :%d\n", ntohs(tcp->dest)-6000);
+      if (ntohs(tcp->dest) >= SERV_PORT && ntohs(tcp->dest) <= SERV_PORT+4)
+         sprintf(data_to_ettercap->user, "On display :%d\n", ntohs(tcp->dest)-SERV_PORT);
       else
          sprintf(data_to_ettercap->user, "\n");
       strcat(data_to_ettercap->pass, "\n");
