@@ -100,8 +100,6 @@ int Doppleganger_Main(char *iface, char *IP1, char *IP2, char *MAC1, char *MAC2)
 
    strcpy(program_argv0, "dopplega");
 
-   Inet_DisableForwarding();
-
    if (strcmp(MAC1,"")) buf1 = Inet_Forge_packet( ETH_HEADER + IP_HEADER + ICMP_HEADER );
    if (strcmp(MAC2,"")) buf2 = Inet_Forge_packet( ETH_HEADER + IP_HEADER + ICMP_HEADER );
 
@@ -160,21 +158,79 @@ int Doppleganger_Main(char *iface, char *IP1, char *IP2, char *MAC1, char *MAC2)
    signal(SIGTERM, Doppleganger_reARP);
    signal(SIGSEGV, Doppleganger_reARP);
 
-   // sends the fake replies
-   loop
+   if ( ((buf1 && !buf2) || (!buf1 && buf2)) && number_of_hosts_in_lan > 1 )  // smart ARP
    {
-      if (getppid() == 1) Doppleganger_reARP(SIGTERM);
-
-      if (buf1) Inet_SendRawPacket(sock, buf1, ETH_HEADER + ARP_HEADER);
-      if (buf2) Inet_SendRawPacket(sock, buf2, ETH_HEADER + ARP_HEADER);
-
-      if (replies<3)
+      #ifdef DEBUG
+         Debug_msg("Doppleganger_Run -- SMART ARPing...");
+      #endif
+      loop
       {
-          sleep(3);
-          replies++;
+         int i;
+
+         if (getppid() == 1) Doppleganger_reARP(SIGTERM);
+
+         for(i = 0; i<number_of_hosts_in_lan; i++)
+         {
+            if (strcmp(Host_In_LAN[i].ip, IP1) && strcmp(Host_In_LAN[i].ip, IP2))   // don't send to the target
+            {
+               char SmartMAC1[6];
+               char SmartMAC2[6];
+
+               if (buf1)
+               {
+                  Inet_GetMACfromString(Host_In_LAN[i].mac, SmartMAC2);
+                  Inet_Forge_ethernet( buf1, MyMAC, SmartMAC2, ETH_P_ARP );
+                  Inet_Forge_arp( buf1+ETH_HEADER, ARPOP_REPLY,
+                       MyMAC, inet_addr(PoorIP1),
+                       SmartMAC2, inet_addr(Host_In_LAN[i].ip) );
+                  Inet_SendRawPacket(sock, buf1, ETH_HEADER + ARP_HEADER);
+               }
+               if (buf2)
+               {
+                  Inet_GetMACfromString(Host_In_LAN[i].mac, SmartMAC1);
+                  Inet_Forge_ethernet( buf2, MyMAC, SmartMAC1, ETH_P_ARP );
+                  Inet_Forge_arp( buf2+ETH_HEADER, ARPOP_REPLY,
+                       MyMAC, inet_addr(PoorIP2),
+                       SmartMAC1, inet_addr(Host_In_LAN[i].ip) );
+                  Inet_SendRawPacket(sock, buf2, ETH_HEADER + ARP_HEADER);
+               }
+            }
+         }
+
+         if (replies<3)
+         {
+            sleep(3);
+            replies++;
+         }
+         else
+            sleep(10);   // Evitiamo di dare nell'occhio trasformando l'hub in un albero di Natale ;)
       }
-      else
-          sleep(10);   // Evitiamo di dare nell'occhio trasformando l'hub in un albero di Natale ;)
+   }
+   else
+   {
+      #ifdef DEBUG
+         if ((buf1 && !buf2) || (!buf1 && buf2))
+            Debug_msg("Doppleganger_Run -- PUBLIC ARPing...");
+         else
+            Debug_msg("Doppleganger_Run -- ARP POISONing...");
+      #endif
+
+      loop
+      {
+         if (getppid() == 1) Doppleganger_reARP(SIGTERM);
+
+         if (buf1) Inet_SendRawPacket(sock, buf1, ETH_HEADER + ARP_HEADER);
+         if (buf2) Inet_SendRawPacket(sock, buf2, ETH_HEADER + ARP_HEADER);
+
+         if (replies<3)
+         {
+             sleep(3);
+             replies++;
+         }
+         else
+             sleep(10);   // Evitiamo di dare nell'occhio trasformando l'hub in un albero di Natale ;)
+      }
+
    }
 
    return(0);
