@@ -201,7 +201,7 @@ int Illithid_ARPBased_GetData(char *iface, char proto, char *IPsource, int PortS
                {
                   datalen = ntohs(udp->len) - UDP_HEADER;
 
-                  if (ok == 1)	// from source
+                  if (ok == 1)   // from source
                   {
                      len -= ETH_HEADER;
                      delta = FilterDrop_MakefilterUDP((u_char *)ip, &len, MTU-40, &ARP_Filter_Source);
@@ -517,6 +517,7 @@ void Illithid_GetConnections(short mode, char *iface, char *IP1p, char *IP2p, ch
       if (len > 0 && ( mode > PUBLICARP || pkttype == PACKET_HOST))
       {
          char ok1 = 0;
+         int dontforward = 0;
 
          eth = (ETH_header *)buffer;
          memcpy(data_to_ettercap.source_mac,eth->source_mac,6);
@@ -584,6 +585,10 @@ void Illithid_GetConnections(short mode, char *iface, char *IP1p, char *IP2p, ch
 
             memcpy(data_to_ettercap.dest_mac,eth->dest_mac,6);
 
+#if defined (HAVE_OPENSSL) && defined (PERMIT_HTTPS)
+            if ( (ip->dest_ip & htonl(0xff000000))==htonl(0x01000000)) ok1=1;    // for https dissection
+#endif
+
             if ( ok1 && ip->proto == IPPROTO_TCP)
             {
                unsigned char *data;
@@ -604,8 +609,8 @@ void Illithid_GetConnections(short mode, char *iface, char *IP1p, char *IP2p, ch
                       data_to_ettercap.flags = tcp->flags;
                       data_to_ettercap.proto = 'T';
                       data_to_ettercap.datalen = datalen;
-                      Dissector_Connections( mode, IPPROTO_TCP, (u_char *)tcp, &data_to_ettercap, Act_Connection_Mode);
-                      Buffer_Put(pipe_with_illithid, &data_to_ettercap, sizeof(CONNECTION));
+                      dontforward = Dissector_Connections( mode, IPPROTO_TCP, (u_char *)tcp, &data_to_ettercap, Act_Connection_Mode);
+                      if (!dontforward) Buffer_Put(pipe_with_illithid, &data_to_ettercap, sizeof(CONNECTION));
                   }
                   else
                   {
@@ -619,8 +624,8 @@ void Illithid_GetConnections(short mode, char *iface, char *IP1p, char *IP2p, ch
                       sniff_data_to_ettercap.datasize = datalen;
                       memset(&sniff_data_to_ettercap.data, 0, sizeof(sniff_data_to_ettercap.data));
                       memcpy(&sniff_data_to_ettercap.data, data, datalen);
-                      Dissector_Connections( mode, IPPROTO_TCP, (u_char *)tcp, &sniff_data_to_ettercap, Act_Connection_Mode);
-                      Buffer_Put(pipe_with_illithid_data, &sniff_data_to_ettercap, sizeof(SNIFFED_DATA));
+                      dontforward = Dissector_Connections( mode, IPPROTO_TCP, (u_char *)tcp, &sniff_data_to_ettercap, Act_Connection_Mode);
+                      if (!dontforward) Buffer_Put(pipe_with_illithid_data, &sniff_data_to_ettercap, sizeof(SNIFFED_DATA));
                   }
                }
             }
@@ -642,8 +647,8 @@ void Illithid_GetConnections(short mode, char *iface, char *IP1p, char *IP2p, ch
                      data_to_ettercap.dest_port = ntohs(udp->dest);
                      data_to_ettercap.proto = 'U';
                      data_to_ettercap.datalen = datalen;
-                     Dissector_Connections( mode, IPPROTO_UDP, (u_char *)udp, &data_to_ettercap, Act_Connection_Mode);
-                     Buffer_Put(pipe_with_illithid, &data_to_ettercap, sizeof(CONNECTION));
+                     dontforward = Dissector_Connections( mode, IPPROTO_UDP, (u_char *)udp, &data_to_ettercap, Act_Connection_Mode);
+                     if (!dontforward) Buffer_Put(pipe_with_illithid, &data_to_ettercap, sizeof(CONNECTION));
                   }
                   else
                   {
@@ -654,12 +659,12 @@ void Illithid_GetConnections(short mode, char *iface, char *IP1p, char *IP2p, ch
                      sniff_data_to_ettercap.datasize = datalen;
                      memset(&sniff_data_to_ettercap.data, 0, sizeof(sniff_data_to_ettercap.data));
                      memcpy(&sniff_data_to_ettercap.data, data, datalen);
-                     Dissector_Connections( mode, IPPROTO_UDP, (u_char *)udp, &sniff_data_to_ettercap, Act_Connection_Mode);
-                     Buffer_Put(pipe_with_illithid_data, &sniff_data_to_ettercap, sizeof(SNIFFED_DATA));
+                     dontforward = Dissector_Connections( mode, IPPROTO_UDP, (u_char *)udp, &sniff_data_to_ettercap, Act_Connection_Mode);
+                     if (!dontforward) Buffer_Put(pipe_with_illithid_data, &sniff_data_to_ettercap, sizeof(SNIFFED_DATA));
                   }
                }
             }
-            if (mode <= PUBLICARP && ok1 && Act_Connection_Mode) Inet_SendRawPacket(sock, buffer, len);
+            if (mode <= PUBLICARP && ok1 && !dontforward && (Act_Connection_Mode || Options.normal)) Inet_SendRawPacket(sock, buffer, len);
          }
       }
 
