@@ -82,6 +82,10 @@ void Inet_Restore_ifr(void);
 void Inet_DisableForwarding(void);
 void Inet_RestoreForwarding(void);
 char *Inet_MacFromIP(unsigned long ip);
+void Inet_UnSetARPEntry(void);
+int Inet_SetARPEntry(unsigned long IP, char MAC[6]);
+void Inet_UnsetRoute(void);
+void Inet_SetRoute(void);
 // ----------------------------------------
 
 
@@ -336,7 +340,7 @@ host_list *Inet_Host_in_LAN_list(char *interface)
 
             Inet_SendRawPacket(sock, buf, ETH_HEADER + ARP_HEADER);
          }
-         usleep(500);
+         usleep(1500);
       }
 
       Inet_Forge_packet_destroy( buf );
@@ -464,7 +468,6 @@ SniffingHost *Inet_NoSniff(void)
    Debug_msg("Inet_NoSniff");
 #endif
 
-   if (SniffTable) free (SniffTable);
    SniffTable = calloc(number_of_hosts_in_lan * 100, sizeof(SniffingHost));
    memset(SniffTable, 0, sizeof(SniffingHost)*number_of_hosts_in_lan);
 
@@ -584,7 +587,7 @@ SniffingHost *Inet_NoSniff(void)
 }
 
 
-int Inet_Fake_Host()
+int Inet_Fake_Host(void)
 {
    unsigned int N_hosts, index, index1=0, index2, base_ip, fake_ip=0;
    unsigned long NetMask;
@@ -598,7 +601,9 @@ int Inet_Fake_Host()
    {
       fake_ip = base_ip|htonl(index);
       for (index2=0; index2 < number_of_hosts_in_lan; index2++)
-         if (fake_ip == inet_addr(Host_In_LAN[index2].ip))
+         if (fake_ip == inet_addr(Host_In_LAN[index2].ip)
+         	|| fake_ip == inet_addr(Host_Source.ip)
+         	|| fake_ip == inet_addr(Host_Dest.ip) )
             break;
       if (index2 == number_of_hosts_in_lan) break;
    }
@@ -693,24 +698,15 @@ int Inet_CheckSwitch()
 int Inet_GetMACfromString(char *mac_string, unsigned char *MAC)
 {
    unsigned int MAC_Add[6];
-   int i, j=0;
-
-   for(i=0; i<strlen(mac_string); i++)
-      if (mac_string[i] == ':')
-         j++;
-
-   if (j < 5)     // bad mac string
-      return -1;
+   int i = 0;
 
    memset(&MAC_Add, 0, 6);
 
-   i=0;
-
    i = sscanf(mac_string,"%02X:%02X:%02X:%02X:%02X:%02X",
       (unsigned int *)&MAC_Add[0],(unsigned int *)&MAC_Add[1],(unsigned int *)&MAC_Add[2],
       (unsigned int *)&MAC_Add[3],(unsigned int *)&MAC_Add[4],(unsigned int *)&MAC_Add[5]);
 
-   if (i == 0) // bad mac string
+   if (i != 6) // bad mac string
       return -1;
 
    for (i=0; i<6; i++)
