@@ -26,7 +26,6 @@
 #include <ncurses.h>
 #include <unistd.h>
 #include <stdlib.h>
-#include <sys/ioctl.h>
 #include <signal.h>
 
 #include "include/ec_interface_sniff.h"
@@ -117,22 +116,19 @@ short ScreenMode;
 
 void Interface_GetWindowSize(void)
 {
-   struct winsize  ws = {0, 0, 0, 0};
-
-   ioctl(0, TIOCGWINSZ, &ws);    // syscall for the window size
 
    W_BOTTOMX1 = 0;
-   W_BOTTOMY1 = ws.ws_row - 4;
-   W_BOTTOMX2 = ws.ws_col - 1;
-   W_BOTTOMY2 = ws.ws_row;
+   W_BOTTOMY1 = LINES - 4;
+   W_BOTTOMX2 = COLS - 1;
+   W_BOTTOMY2 = LINES;
 
    W_MAINX1 = 0;
-   W_MAINX2 = ws.ws_col - 1;
+   W_MAINX2 = COLS - 1;
    W_MAINY2 = W_BOTTOMY1 - 1;
 
    W_TOPX1 = 0;
    W_TOPY1 = 0;
-   W_TOPX2 = ws.ws_col - 1;
+   W_TOPX2 = COLS - 1;
 
    W_TOPY2 = W_TOPY1 + 4;
    W_MAINY1 = W_TOPY2 + 1;
