@@ -34,10 +34,12 @@
 #include "include/ec_decodedata.h"
 #include "include/ec_illithid.h"
 #include "include/ec_doppleganger.h"
+#include "include/ec_grell.h"
 #include "include/ec_inet.h"
 #include "include/ec_inet_forge.h"
 #include "include/ec_inet_structures.h"
 #include "include/ec_buffer.h"
+#include "include/ec_logtofile.h"
 
 #ifdef DEBUG
    #include "include/ec_debug.h"
@@ -141,8 +143,11 @@ void Interface_Sniff_InitList(void)
    werase(bottom_window);
    mvwprintw(bottom_window, 0, 1, " %s", Conn_Between_Hosts[Conn_Pointer].user);
    mvwprintw(bottom_window, 1, 1, " %s", Conn_Between_Hosts[Conn_Pointer].pass);
-   snprintf(info, W_MAINX2 - 23, "%s", Conn_Between_Hosts[Conn_Pointer].info);
-   mvwprintw(bottom_window, 1, 25, " %s", info);
+   snprintf(info, W_MAINX2 - 28, "%s", Conn_Between_Hosts[Conn_Pointer].info);
+   if (strlen(info)+1 == W_MAINX2 - 28)
+      mvwprintw(bottom_window, 1, 25, " %s->", info);
+   else
+      mvwprintw(bottom_window, 1, 25, " %s", info);
 
    wnoutrefresh(bottom_window);
    wnoutrefresh(main_window);
@@ -220,8 +225,11 @@ void Interface_Sniff_PointItem(char direction)
    werase(bottom_window);
    mvwprintw(bottom_window, 0, 1, " %s", Conn_Between_Hosts[Conn_Pointer].user);
    mvwprintw(bottom_window, 1, 1, " %s", Conn_Between_Hosts[Conn_Pointer].pass);
-   snprintf(info, W_MAINX2 - 23, "%s", Conn_Between_Hosts[Conn_Pointer].info);
-   mvwprintw(bottom_window, 1, 25, " %s", info);
+   snprintf(info, W_MAINX2 - 28, "%s", Conn_Between_Hosts[Conn_Pointer].info);
+   if (strlen(info)+1 == W_MAINX2 - 28)
+      mvwprintw(bottom_window, 1, 25, " %s->", info);
+   else
+      mvwprintw(bottom_window, 1, 25, " %s", info);
 
    wnoutrefresh(bottom_window);
    wnoutrefresh(main_window);
@@ -352,10 +360,12 @@ void Interface_Sniff_ActiveDissecor(short mode)
    {
       case 1:  wbkgdset(top_window, COLOR_PAIR(BOTTOM_COLOR));
                mvwprintw(top_window, 2, 49, "ON ");
+               if (mode == PUBLICARP) wprintw(top_window," (only PUBLIC ARP)");
                break;
 
       case 0:  wbkgdset(top_window, COLOR_PAIR(BOTTOM_COLOR));
                mvwprintw(top_window, 2, 49, "OFF");
+               if (mode == PUBLICARP) wprintw(top_window," (only PUBLIC ARP)");
                break;
    }
 
@@ -370,6 +380,9 @@ void Interface_Sniff_Run(short mode)
 {
    int KeyPress;
    int Illithid_pid = 0, Dopple_pid = 0;
+   #if defined (HAVE_OPENSSL) && defined (PERMIT_HTTPS)
+      int Grell_pid = 0;
+   #endif
    fd_set msk_fd;
    struct timeval TimeOut;
    CONNECTION data_from_illithid;
@@ -388,7 +401,7 @@ void Interface_Sniff_Run(short mode)
    wnoutrefresh(bottom_window);
    doupdate();
 
-   if (mode != ARPBASED )
+   if (mode > PUBLICARP )
       active_dissector = 0;
 
    Interface_Sniff_ActiveDissecor(mode);
@@ -409,6 +422,11 @@ void Interface_Sniff_Run(short mode)
                         Illithid_pid = Illithid_ARPBased_GetConnections(Options.netiface, Host_Source.ip, Host_Dest.ip, Host_Source.mac, Host_Dest.mac);
                      else
                         Illithid_pid = Illithid_PublicARP_GetConnections(Options.netiface, Host_Source.ip, Host_Dest.ip, Host_Source.mac, Host_Dest.mac);
+
+                     #if defined (HAVE_OPENSSL) && defined (PERMIT_HTTPS)
+                        Grell_pid = Grell_Run();
+                     #endif
+
                      break;
       case IPBASED:
                      Illithid_pid = Illithid_IPBased_GetConnections(Options.netiface, Host_Source.ip, Host_Dest.ip);
@@ -429,7 +447,7 @@ void Interface_Sniff_Run(short mode)
 
       select(FOPEN_MAX, &msk_fd, (fd_set *) 0, (fd_set *) 0, &TimeOut);
 
-      memset(&data_from_illithid, 0, sizeof(CONNECTION));
+      //memset(&data_from_illithid, 0, sizeof(CONNECTION));
       datalen = Buffer_Get(pipe_with_illithid, &data_from_illithid, sizeof(CONNECTION));
 
       if (datalen > 0)
@@ -466,10 +484,16 @@ void Interface_Sniff_Run(short mode)
             case KEY_RETURN:
                      if (Conn_Between_Hosts[Conn_Pointer].source_ip == NULL) break;   // no connections
                      wmove(bottom_window, 0, 0);
+                     mvwprintw(top_window, 2, 52, "                    ");
                      if ( mode == PUBLICARP )
                          kill(Dopple_pid,SIGTERM);    // kill publicARP doppleganger...
 
                      kill(Illithid_pid, SIGUSR2);
+                     #if defined (HAVE_OPENSSL) && defined (PERMIT_HTTPS)
+                        if (Grell_pid)
+                           if ( kill(-1*Grell_pid, SIGUSR2) == -1)   // send the signal to the Grell's group (-PID)
+                              kill(Grell_pid, SIGUSR2);
+                     #endif
                      Interface_Sniff_Data_Run(Conn_Between_Hosts[Conn_Pointer].source_ip,
                                               Conn_Between_Hosts[Conn_Pointer].source_port,
                                               Conn_Between_Hosts[Conn_Pointer].dest_ip,
@@ -481,9 +505,15 @@ void Interface_Sniff_Run(short mode)
                                               mode);
                      // wait and then...
                      kill(Illithid_pid, SIGUSR2);
+                     #if defined (HAVE_OPENSSL) && defined (PERMIT_HTTPS)
+                        if (Grell_pid)
+                           if ( kill(-1*Grell_pid, SIGUSR2) == -1)   // send the signal to the Grell's group (-PID)
+                              kill(Grell_pid, SIGUSR2);
+                     #endif
                      if ( mode == PUBLICARP )
                          Dopple_pid = Doppleganger_Run(Options.netiface, Host_Source.ip, Host_Dest.ip, Host_Source.mac, Host_Dest.mac);
 
+                     Interface_Sniff_ActiveDissecor(mode);
                      Interface_Sniff_InitList();
                      break;
 
@@ -522,16 +552,27 @@ void Interface_Sniff_Run(short mode)
                      Interface_Redraw();
                      break;
 
+            case 'L':
+            case 'l':
+                     {
+                        char *file;
+                        char mesg[80];
+                        file = LogToFile_DumpPass();
+                        snprintf(mesg, 80, "Passwords dumped to %s", file);
+                        Interface_PopUp(mesg);
+                     }
+                     break;
+
 #ifdef PERMIT_PLUGINS
-	         case 'P':
-   	      case 'p':
-      	            Interface_Plugins_Run();
-         	         break;
+            case 'P':
+            case 'p':
+                     Interface_Plugins_Run();
+                     break;
 #endif
 
             case 'A':
             case 'a':
-                     if (mode == ARPBASED)
+                     if (mode <= PUBLICARP)
                      {
                         kill(Illithid_pid, SIGUSR1);  // activate/deactivate special dissector
                         kill(getpid(), SIGUSR1);
@@ -539,7 +580,7 @@ void Interface_Sniff_Run(short mode)
                      }
                      else
                      {
-                        Interface_PopUp("ACTIVE dissector is available only in ARP BASED mode !!");
+                        Interface_PopUp("ACTIVE dissector is available only in ARP mode !!");
                      }
                      break;
 
@@ -555,9 +596,10 @@ void Interface_Sniff_Run(short mode)
                            "[return]  - sniff the selected connection",
                            "[xX]      - Packet Forge",
                            "[aA]      - enable/disable ACTIVE password collectors",
+                           "[lL]      - log all collected passwords to a file",
                            "[kK]      - kill the connection (be careful !)",
 #ifdef PERMIT_PLUGINS
-                       		"[pP]      - run a plugin",
+                           "[pP]      - run a plugin",
 #endif
                            "[dD]      - resolve ip via DNS",
                            "[rR]      - refresh the list",
@@ -571,6 +613,9 @@ void Interface_Sniff_Run(short mode)
             case 'q':
                      kill(Illithid_pid, SIGTERM);
                      if (Dopple_pid) kill(Dopple_pid, SIGTERM);
+                     #if defined (HAVE_OPENSSL) && defined (PERMIT_HTTPS)
+                        if (Grell_pid) kill(Grell_pid, SIGTERM);
+                     #endif
                      #ifdef DEBUG
                         Debug_msg("Interface_Sniff_END");
                      #endif
@@ -588,6 +633,9 @@ void Interface_Sniff_Run(short mode)
                      #endif
                      kill(Illithid_pid, SIGTERM);
                      if (Dopple_pid) kill(Dopple_pid, SIGTERM);
+                     #if defined (HAVE_OPENSSL) && defined (PERMIT_HTTPS)
+                        if (Grell_pid) kill(Grell_pid, SIGTERM);
+                     #endif
                      Interface_WExit("They are safe!!  for now... ");
                      break;
          }
