@@ -74,7 +74,7 @@ void Interface_Sniff_Data_StopCont(void);
 void Interface_Sniff_Data_View(short mode);
 void Interface_Sniff_Data_Scroll(short direction);
 void Interface_Sniff_Data_DrawScroller(void);
-void Interface_Sniff_Data_Inject(char proto, char *app);
+void Interface_Sniff_Data_Inject(char proto, char *app, char *ipsource, char *ipdest);
 void Interface_Sniff_Data_Filter(void);
 void Interface_Sniff_Data_ActiveFilter(short mode);
 
@@ -483,7 +483,7 @@ void Interface_Sniff_Data_Scroll(short direction)
 
 
 
-void Interface_Sniff_Data_Inject(char proto, char *app)
+void Interface_Sniff_Data_Inject(char proto, char *app, char *ipsource, char *ipdest)
 {
 
    char inject_data[MAX_INJECT];
@@ -524,7 +524,7 @@ void Interface_Sniff_Data_Inject(char proto, char *app)
       wbkgdset(bottom_window, COLOR_PAIR(BOTTOM_COLOR));
       wprintw(bottom_window, "%d ", inject_tos += data_len);
       wbkgdset(bottom_window, COLOR_PAIR(SNIFF_COLOR));
-      wprintw(bottom_window, "chars injected to %s", Host_Source.ip);
+      wprintw(bottom_window, "chars injected to %s", ipsource);
    }
    else
    {
@@ -533,7 +533,7 @@ void Interface_Sniff_Data_Inject(char proto, char *app)
       wbkgdset(bottom_window, COLOR_PAIR(BOTTOM_COLOR));
       wprintw(bottom_window, "%d ", inject_tod += data_len);
       wbkgdset(bottom_window, COLOR_PAIR(SNIFF_COLOR));
-      wprintw(bottom_window, "chars injected to %s", Host_Dest.ip);
+      wprintw(bottom_window, "chars injected to %s", ipdest);
    }
 
    wnoutrefresh(bottom_window);
@@ -792,7 +792,7 @@ void Interface_Sniff_Data_Run(char *ipsource, int portsource, char *ipdest, int
                         Interface_Sniff_Data_Redraw();
                      }
                      else
-                        Interface_Sniff_Data_Inject(proto, app);
+                        Interface_Sniff_Data_Inject(proto, app, ipsource, ipdest);
                   }
                   else
                   {
