@@ -51,6 +51,7 @@ FILE * LogToFile_open_collect();
 void LogToFile_freelist(LOGGED_DATA *head);
 void LogToFile_close();
 void LogToFile_FilteredData(u_char * buf_ip);
+char *LogToFile_DumpPass(void);
 
 // -------------------------------
 
@@ -218,4 +219,46 @@ void LogToFile_FilteredData(u_char * buf_ip)
 
 }
 
+
+char *LogToFile_DumpPass(void)
+{
+   static char logname[100];
+   FILE *fto;
+   int i;
+   time_t tt = time(NULL);
+   struct tm *dd = localtime(&tt);
+
+#ifdef DEBUG
+   Debug_msg("LogToFile_DumpPass");
+#endif
+
+   sprintf(logname, "%04d%02d%02d-%02d:%02d:%02d-DumpedPassword.log", dd->tm_year+1900, dd->tm_mon+1, dd->tm_mday, dd->tm_hour, dd->tm_min, dd->tm_sec);
+
+   fto = fopen(logname, "a");
+   if (fto == NULL)
+         Error_msg("ec_logtofile:%d fopen(%s) | ERRNO : %d | %s", logname, __LINE__, errno, strerror(errno));
+
+   for (i=0; i < number_of_connections; i++)
+   {
+      if (Conn_Between_Hosts[i].user[0] != 0 &&  Conn_Between_Hosts[i].pass[0] != 0)
+      {
+         fprintf(fto, "\n\n%s:%d -> %s:%d\t\t%s\n\n", Conn_Between_Hosts[i].source_ip,
+                                                      Conn_Between_Hosts[i].source_port,
+                                                      Conn_Between_Hosts[i].dest_ip,
+                                                      Conn_Between_Hosts[i].dest_port,
+                                                      Conn_Between_Hosts[i].type
+                                                      );
+         fprintf(fto, "%s\n", Conn_Between_Hosts[i].user);
+         fprintf(fto, "%s\n", Conn_Between_Hosts[i].pass);
+         if (strlen(Conn_Between_Hosts[i].info))
+            fprintf(fto, "\n%s\n", Conn_Between_Hosts[i].info);
+         fflush(fto);
+      }
+   }
+
+   fclose(fto);
+   return logname;
+}
+
+
 /* EOF */
