@@ -109,7 +109,7 @@ int main(int argc, char *argv[])
 }
 #endif
 
-	if (Parser_ParseOptions(argc, argv) == 1)
+	if (Parser_ParseOptions(argc, argv) == 1)	// config file
 		Parser_ParseConfFile(optarg);
 
    if (!strcmp(Options.netiface, ""))        // set the default interface
@@ -123,7 +123,6 @@ int main(int argc, char *argv[])
       Error_msg("Network Interface %s is invalid !!", Options.netiface);
 #endif
 
-
    if (Options.normal)
       Main_Normal();
    else
@@ -174,6 +173,7 @@ void Main_Usage(void)
 #endif
 	fprintf (stdout, "  -e, --etterconf [filename]   use the config file instead of command line options\n\n");
 	fprintf (stdout, "  -d, --dontresolve            don't resolve the IPs (speed the startup)\n\n");
+   fprintf (stdout, "  -k, --newcert                create a new SSL cert file for Grell (HTTPS dissector)\n\n");
    fprintf (stdout, "  -v, --version                print version\n\n");
    fprintf (stdout, "  -h, --help                   print this help\n\n");
    fprintf (stdout, "\n");
@@ -200,11 +200,34 @@ void Main_Interactive(void)
    	Error_msg("ec_main:%d ioctl(TIOCGWINSZ) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
 
    if ( (ws.ws_row < 25) || (ws.ws_col < 80) )
-      Error_msg("Screen must be at least 25x80 !!");
+   {
+   	char *p;
+   	short cols = ws.ws_col;
+   	short rows = ws.ws_row;
+
+   	#ifdef DEBUG
+      	Debug_msg("Main_Interactive -- screen wide %dx%d (TIOCGWINSZ)", ws.ws_row, ws.ws_col);
+   	#endif
+
+   	if ((p = getenv("LINES")))
+   		rows = atoi(p);
+   	if ((p = getenv("COLUMNS")))
+   		cols = atoi(p);
+
+   	#ifdef DEBUG
+      	Debug_msg("Main_Interactive -- screen wide %sx%s (getenv)", getenv("LINES"), getenv("COLUMNS"));
+   	#endif
+
+		if (rows < 25 || cols < 80)
+      	Error_msg("Screen must be at least 25x80 !!");
+   }
 
    if (!Options.silent) printf("Building host list for netmask %s, please wait...\n", Inet_MySubnet());
    number_of_hosts_in_lan = Inet_HostInLAN();
 
+// FIXME
+   Inet_DisableForwarding();
+
    Interface_InitTitle(Host_In_LAN[0].ip, Host_In_LAN[0].mac, Inet_MySubnet());
    Interface_InitScreen();
    Interface_Run();
