@@ -35,6 +35,7 @@
 #include "include/ec_dissector.h"
 #include "include/ec_illithid.h"
 #include "include/ec_doppleganger.h"
+#include "include/ec_grell.h"
 #include "include/ec_buffer.h"
 #include "include/ec_plugins.h"
 #include "include/ec_fingerprint.h"
@@ -74,6 +75,7 @@ void Simple_CheckForPoisoner(void);
 void Simple_FingerPrint(void);
 void Simple_CheckForSwitch(void);
 void Simple_Demonize(void);
+void Simple_CreateCertFile(void);
 
 //---------------------------------
 
@@ -120,6 +122,42 @@ void Simple_FingerPrint(void)
 
 
 
+void Simple_CreateCertFile(void)
+{
+
+#ifdef DEBUG
+   Debug_msg("Simple_CreateCertFile");
+#endif
+
+#if defined (HAVE_OPENSSL) && defined (PERMIT_HTTPS)
+
+	// XXX - i am cheap and dirty...  as dug song said in the webmitm source code...
+	// ripped form it
+
+	if (system("openssl genrsa -out " CERT_FILE " 1024") != 0)
+		Error_msg("ec_simple:%d system() | could not launch openssl (check the path)", __LINE__);
+
+	if (system("openssl req -new -key " CERT_FILE " -out " CERT_FILE ".csr") != 0)
+		Error_msg("ec_simple:%d system() | could not launch openssl (check the path)", __LINE__);
+
+	if (system("openssl x509 -req -days 365 -in " CERT_FILE ".csr -signkey " CERT_FILE " -out " CERT_FILE ".new"))
+		Error_msg("ec_simple:%d system() | could not launch openssl (check the path)", __LINE__);
+
+	if (system("cat " CERT_FILE ".new >> " CERT_FILE) != 0)
+		Error_msg("ec_simple:%d system() | could not launch openssl (check the path)", __LINE__);
+
+	unlink(CERT_FILE ".new");
+	unlink(CERT_FILE ".csr");
+
+	fprintf(stdout, "\nOpenssl [%s] certificate generated in ./\n\n", CERT_FILE);
+#else
+	Error_msg("ettercap was compiled without HTTPS support...");
+#endif
+	exit(0);
+}
+
+
+
 void Simple_CheckForSwitch(void)
 {
    short type;
@@ -295,6 +333,9 @@ void Simple_Demonize(void)
 void Simple_Run(void)
 {
    int Illithid_pid = 0, Dopple_pid = 0, Illithid_pid2 = 0;
+   #if defined (HAVE_OPENSSL) && defined (PERMIT_HTTPS)
+   	int Grell_pid = 0;
+   #endif
    int i, index_source=-1, index_dest=-1;
    char view = ASCII_VIEW;
    char stop = 0;
@@ -305,6 +346,7 @@ void Simple_Run(void)
    int datalen;
    char source[16], dest[16];
    char proto = 'T';
+   TIME_DECLARE;
 
    if (Options.udp) proto = 'U';
 
@@ -385,10 +427,11 @@ void Simple_Run(void)
 
    // it is ok...
 
-   active_dissector = 0;
-
    if (Options.arpsniff)      // Doppleganger born...
+   {
+   	Inet_DisableForwarding();
 	   Dopple_pid = Doppleganger_Run(Options.netiface, Host_Source.ip, Host_Dest.ip, Host_Source.mac, Host_Dest.mac);
+	}
 
    if (!Options.quiet) printf("\nPress 'h' for help...\n\n");
 
@@ -397,10 +440,24 @@ void Simple_Run(void)
 
    if (Options.arpsniff)
    {
-      if (!Options.quiet) printf(" Sniffing (ARP based) : %s:%d <--> %s <--> %s:%d\n\n", source, Host_Source.port, Inet_MyIPAddress(), dest, Host_Dest.port);
-      if (!Options.collect) Connection_Mode=0;
-      Illithid_pid = Illithid_ARPBased_GetConnections(Options.netiface, Host_Source.ip,  Host_Dest.ip, Host_Source.mac, Host_Dest.mac);
-      if (!Options.collect) Illithid_pid2 = Illithid_ARPBased_GetData(Options.netiface, proto, Host_Source.ip, Host_Source.port, Host_Dest.ip, Host_Dest.port, Host_Source.mac, Host_Dest.mac);
+   	if (strcmp(Host_Source.ip, ""))	// arp based
+   	{
+      	if (!Options.quiet) printf(" Sniffing (ARP based) : %s:%d <--> %s <--> %s:%d\n\n", source, Host_Source.port, Inet_MyIPAddress(), dest, Host_Dest.port);
+      	if (!Options.collect) Connection_Mode=0;
+      	Illithid_pid = Illithid_ARPBased_GetConnections(Options.netiface, Host_Source.ip,  Host_Dest.ip, Host_Source.mac, Host_Dest.mac);
+         #if defined (HAVE_OPENSSL) && defined (PERMIT_HTTPS)
+         	Grell_pid = Grell_Run();
+         #endif
+      }
+      else	// public arp
+      {
+			if (!Options.quiet) printf(" Sniffing (PUBLIC ARP) : %s:%d --> %s --> %s:%d  (half-duplex)\n\n", source, Host_Source.port, Inet_MyIPAddress(), dest, Host_Dest.port);
+      	if (!Options.collect) Connection_Mode=0;
+      	Illithid_pid = Illithid_PublicARP_GetConnections(Options.netiface, Host_Source.ip,  Host_Dest.ip, Host_Source.mac, Host_Dest.mac);
+         #if defined (HAVE_OPENSSL) && defined (PERMIT_HTTPS)
+         	Grell_pid = Grell_Run();
+         #endif
+      }
    }
    else if (Options.sniff)
    {
@@ -421,7 +478,6 @@ void Simple_Run(void)
 
       if(!Options.quiet)
       {
-
          #ifdef HAVE_TERMIOS_H
             set_raw_term();   // non blocking stdin... yes this work !!
          #else
@@ -432,6 +488,8 @@ void Simple_Run(void)
          #endif
       }
 
+		TIME_START;
+
       loop
       {
 
@@ -467,7 +525,7 @@ void Simple_Run(void)
                case 'l':
                      if (logtofile)
                      {
-                        printf("\n\nStopping the log to file(s)...\n\n");
+                        printf("\n\nStop logging to file(s)...\n\n");
                         if (logtofile == 2) fclose(logcollect);
                         if (logtofile == 1) LogToFile_close();
                         logtofile = 0;
@@ -522,6 +580,9 @@ void Simple_Run(void)
                      if (logtofile == 1) LogToFile_close();
                      if (Illithid_pid2) kill(Illithid_pid2,SIGTERM);
                      if (Dopple_pid) kill(Dopple_pid, SIGTERM);
+                     #if defined (HAVE_OPENSSL) && defined (PERMIT_HTTPS)
+         					if (Grell_pid) kill(Grell_pid, SIGTERM);
+         				#endif
                      exit(0);
                      break;
             }
@@ -534,12 +595,8 @@ void Simple_Run(void)
 
          if (datalen>0)
          {
-
-            time_t tt;
-            struct tm *dd;
-
-            tt = time(NULL);
-            dd = localtime(&tt);
+            time_t tt = time(NULL);
+            struct tm *dd = localtime(&tt);
 
             if (Options.collect)
             {
@@ -548,12 +605,11 @@ void Simple_Run(void)
 
                for (i=0; i < number_of_connections; i++)
                {
-                  if (Conn_Between_Hosts[i].user[0] != 0 &&  Conn_Between_Hosts[i].pass[0] != 0 &&
-                      Conn_Between_Hosts[i].user[0] != 1 &&  Conn_Between_Hosts[i].pass[0] != 1 )
+                  if (Conn_Between_Hosts[i].user[0] != 0 &&  Conn_Between_Hosts[i].pass[0] != 0)
                   {
                      if (logtofile == 2)
                      {
-                        fprintf(logcollect, "\n\n%02d:%02d:%02d  %s:%d -> %s:%d\t\t%s\n\n", dd->tm_hour, dd->tm_min, dd->tm_sec,
+                        fprintf(logcollect, "\n\n%02d:%02d:%02d  %s:%d <--> %s:%d\t\t%s\n\n", dd->tm_hour, dd->tm_min, dd->tm_sec,
                                              Conn_Between_Hosts[i].source_ip,
                                              Conn_Between_Hosts[i].source_port,
                                              Conn_Between_Hosts[i].dest_ip,
@@ -570,7 +626,7 @@ void Simple_Run(void)
 
                      if (!Options.quiet)
                      {
-                        printf("\n\n%02d:%02d:%02d  %s:%d -> %s:%d\t\t%s\n\n", dd->tm_hour, dd->tm_min, dd->tm_sec,
+                        printf("\n\n%02d:%02d:%02d  %s:%d <--> %s:%d\t\t%s\n\n", dd->tm_hour, dd->tm_min, dd->tm_sec,
                               Conn_Between_Hosts[i].source_ip,
                               Conn_Between_Hosts[i].source_port,
                               Conn_Between_Hosts[i].dest_ip,
@@ -583,14 +639,24 @@ void Simple_Run(void)
                         if (strlen(Conn_Between_Hosts[i].info))
                           printf("\n%s\n", Conn_Between_Hosts[i].info);
                      }
-                     Conn_Between_Hosts[i].user[0] = 1;  // dont display in the future...
-                     Conn_Between_Hosts[i].pass[0] = 1;  // dont display in the future...
+                     memset(&Conn_Between_Hosts[i], 0, sizeof(CONNECTION));  // dont display in the future...
+                  	#ifdef DEBUG
+               			Debug_msg("\tConnection %d displayed and deleted...", i+1);
+               		#endif
                   }
+               }	// end for
+               TIME_FINISH;
+               if (TIME_ELAPSED >= 300)
+               {
+               	#ifdef DEBUG
+               		Debug_msg("\tConnection List refreshed after %.0f minutes...", (TIME_ELAPSED)/60);
+               	#endif
+               	TIME_START;									// after 300 seconds (5 min)...
+               	Decodedata_RefreshConnectionList(); // periodically refresh the list...
                }
-               if (number_of_connections >= 15) Decodedata_RefreshConnectionList(); // periodically refresh the list...
             }
             else // !collect
-            if (proto == data_from_illithid.proto && Illithid_ToBeSniffed(Host_Source.ip,Host_Source.port,Host_Dest.ip,Host_Dest.port,&data_from_illithid))
+            if (proto == data_from_illithid.proto && Illithid_ToBeSniffed("", Host_Source.port, "", Host_Dest.port, &data_from_illithid))
             {
 
                if (logtofile) LogToFile(&data_from_illithid);
