@@ -1,12 +1,24 @@
 
+// structures....
+
+typedef struct {
+   char mode;
+   short proto;
+   short port;
+   int (*dissector)(u_char *, void *, int, short);
+   char active;
+   char name[10];
+} DISSECTOR;
+
 // functions...
-extern void Dissector_Connections( char mode, short proto, u_char *data, void *data_to_ettercap, int Conn_Mode );
+extern int Dissector_Connections( char mode, short proto, u_char *data, void *data_to_ettercap, int Conn_Mode );
+extern void Dissector_SetHandle( char *name, char active, short port, short proto);
 extern int Dissector_StateMachine_GetStatus(CONNECTION *data_to_ettercap);
 extern int Dissector_StateMachine_SetStatus(CONNECTION *data_to_ettercap, char status);
 extern int Dissector_base64decode(char *bufplain, const char *bufcoded);
 
 // macros....
-#define FUNC_DISSECTOR(func) int func( u_char *data, void *vdata_to_ettercap, int Conn_Mode )
+#define FUNC_DISSECTOR(func) int func( u_char *data, void *vdata_to_ettercap, int Conn_Mode, short SERV_PORT )
 
 #define ONLY_CONNECTION    CONNECTION *data_to_ettercap; \
                            if (!Conn_Mode) return 0; \
@@ -15,7 +27,7 @@ extern int Dissector_base64decode(char *bufplain, const char *bufcoded);
 #define DATA_DISSECTOR     CONNECTION *data_to_ettercap; \
                            SNIFFED_DATA *sniff_data_to_ettercap; \
                            data_to_ettercap = (CONNECTION *)vdata_to_ettercap; \
-   								sniff_data_to_ettercap = (SNIFFED_DATA *)vdata_to_ettercap
+                           sniff_data_to_ettercap = (SNIFFED_DATA *)vdata_to_ettercap
 
 
 // dissectors....
@@ -30,14 +42,17 @@ extern FUNC_DISSECTOR(Dissector_nntp);     // 119
 extern FUNC_DISSECTOR(Dissector_smb);      // 139
 extern FUNC_DISSECTOR(Dissector_imap);     // 143 220
 extern FUNC_DISSECTOR(Dissector_bgp);      // 179
+#if defined (HAVE_OPENSSL) && defined (PERMIT_HTTPS)
+extern FUNC_DISSECTOR(Dissector_https);    // 443
+#endif
 extern FUNC_DISSECTOR(Dissector_rlogin);   // 512 513 514
-extern FUNC_DISSECTOR(Dissector_rip);      // 520					UDP
+extern FUNC_DISSECTOR(Dissector_rip);      // 520              UDP
 extern FUNC_DISSECTOR(Dissector_socks);    // 1080
 extern FUNC_DISSECTOR(Dissector_mysql);    // 3306
-extern FUNC_DISSECTOR(Dissector_icq);      // 4000	ALL_P			UDP
+extern FUNC_DISSECTOR(Dissector_icq);      // 4000             UDP
 extern FUNC_DISSECTOR(Dissector_vnc);      // 5900-5905
 extern FUNC_DISSECTOR(Dissector_x11);      // 6000-6005
 extern FUNC_DISSECTOR(Dissector_napster);  // 6666 7777 8888
-extern FUNC_DISSECTOR(Dissector_irc); 		 // 6667-6669
+extern FUNC_DISSECTOR(Dissector_irc);      // 6667-6669
 
 /* EOF */
