@@ -3,7 +3,7 @@
 #endif
 
 #define DEVEL_RELEASE 0
-#define VERSION "0.4.3"
+#define VERSION "0.5.0"
 #define PROGRAM "ettercap"
 #define AUTHORS "ALoR & NaGA"
 
@@ -13,12 +13,12 @@ extern char *program_argv0;
 
 #include <sys/types.h>
 
-#ifndef HAVE_STRLCAT					// missing functions
-	#include "../missing/strlcat.h"
+#ifndef HAVE_STRLCAT             // missing functions
+   #include "../missing/strlcat.h"
 #endif
 
-#ifndef HAVE_MEMMEM					// missing functions
-	#include "../missing/memmem.h"
+#ifndef HAVE_MEMMEM              // missing functions
+   #include "../missing/memmem.h"
 #endif
 
 #ifdef HAVE_ATEXIT
@@ -74,8 +74,8 @@ typedef struct sniffed_data   // data through the pipe with illithid
 {
    char source_ip[16];
    char dest_ip[16];
-   short source_port;
-   short dest_port;
+   u_short source_port;
+   u_short dest_port;
    u_long seq;
    u_long ack_seq;
    char flags;
@@ -98,8 +98,8 @@ typedef struct connection        // connection list
    char dest_ip[16];
    char source_mac[20];
    char dest_mac[20];
-   short source_port;
-   short dest_port;
+   u_short source_port;
+   u_short dest_port;
    u_long source_seq;
    u_long dest_seq;
    char flags;
@@ -113,18 +113,18 @@ typedef struct connection        // connection list
 } CONNECTION;
 
 
-#define MAX_INJECT 1000  			// max number of injected chars
-#define MAX_FILTER 200	 			// max filter length
+#define MAX_INJECT 1000          // max number of injected chars
+#define MAX_FILTER 200           // max filter length
 
-typedef struct {						// filter structure (ec_filterdrop.c)
-	u_char search[MAX_FILTER];
-	short slen;
-	u_char replace[MAX_FILTER];
-	short rlen;
-	char type;
+typedef struct {                 // filter structure (ec_filterdrop.c)
+   u_char search[MAX_FILTER];
+   short slen;
+   u_char replace[MAX_FILTER];
+   short rlen;
+   char type;
 } DROP_FILTER;
 
-extern DROP_FILTER ARP_Filter_Source;	// ec_filterdrop.c
+extern DROP_FILTER ARP_Filter_Source;  // ec_filterdrop.c
 extern DROP_FILTER ARP_Filter_Dest;
 
 extern CONNECTION *Conn_Between_Hosts;
@@ -158,4 +158,10 @@ extern int Connection_Mode;      // ec_illithid.c
 #define IPBASED   2
 #define MACBASED  3
 
+#if defined (HAVE_OPENSSL) && defined (PERMIT_HTTPS)
+   #define HTTPS_Local_Port (unsigned short)1012         // local port for HTTPS dissection
+   #define Proxy_Local_Port (unsigned short)1013
+	#define CERT_FILE "grell_ssl.crt"
+#endif
+
 /* EOF */
