@@ -20,10 +20,8 @@
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
-
 // This file is included from ../ec_inet.c
 
-
 int Inet_FindIFace(char *iface)
 {
    #define MAX_IFACE 20
@@ -201,21 +199,21 @@ int Inet_GetRawPacket(int sock, char *buffer, int MTU, short *type)
 {
    int len = 0;
    socklen_t fromlen;
-#ifdef HAVE_PF_PACKET
-   struct sockaddr_ll from;
-#else
+//#ifdef HAVE_PF_PACKET
+//   struct sockaddr_ll from;
+//#else
    struct sockaddr from;
    static char MyMAC[6]={0x65,0x74,0x74,0x65,0x72,0x63};
-#endif
+//#endif
 
    fromlen = sizeof(from);
    len = recvfrom(sock, buffer, MTU+64, MSG_TRUNC, (struct sockaddr *)&from, &fromlen);
 
    if (len > MTU + ETH_HEADER) len = MTU + ETH_HEADER;   // workaround for bugged kernel (2.2.14)
 
-#ifdef HAVE_PF_PACKET
-   if (type != NULL) *type = from.sll_pkttype;
-#else
+//#ifdef HAVE_PF_PACKET
+//   if (type != NULL) *type = from.sll_pkttype;
+//#else
    // the address returned for SOCK_PACKET lacks the packet type information.
    if (type != NULL)
    {
@@ -226,7 +224,7 @@ int Inet_GetRawPacket(int sock, char *buffer, int MTU, short *type)
        else
            *type = 1; // !PACKET_HOST
    }
-#endif
+//#endif
 
    // TODO
    // handle fragmented packets...
@@ -334,7 +332,6 @@ void Inet_Restore_ifr(void)
 }
 
 
-
 void Inet_DisableForwarding(void)
 {
    FILE *fd;
@@ -343,7 +340,7 @@ void Inet_DisableForwarding(void)
    if (fd < 0 )
    {
       #ifdef DEBUG
-         Debug_msg("ec_Inet_linux:%d fopen(/proc/sys/net/ipv4/ip_forward) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+         Debug_msg("ec_Inet_linux:%d fopen(/proc/sys/net/ipv4/ip_forward) | ERRNO : %d | %s \n", __LINE__, errno, sys_errlist[errno]);
       #endif
       return;
    }
@@ -361,14 +358,13 @@ void Inet_DisableForwarding(void)
    if (fd < 0 )
    {
       #ifdef DEBUG
-         Debug_msg("ec_Inet_linux:%d fopen(/proc/sys/net/ipv4/ip_forward) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+         Debug_msg("ec_Inet_linux:%d fopen(/proc/sys/net/ipv4/ip_forward) | ERRNO : %d | %s \n", __LINE__, errno, sys_errlist[errno]);
       #endif
       return;
    }
 
    fprintf(fd, "0");
    fclose(fd);
-
 }
 
 
@@ -377,11 +373,13 @@ void Inet_RestoreForwarding(void)
 {
    FILE *fd;
 
+   if (strcmp(program_argv0, PROGRAM)) return;
+
    fd = fopen("/proc/sys/net/ipv4/ip_forward", "w");
    if (fd < 0 )
    {
       #ifdef DEBUG
-         Debug_msg("ec_Inet_linux:%d fopen(/proc/sys/net/ipv4/ip_forward) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+         Debug_msg("ec_Inet_linux:%d fopen(/proc/sys/net/ipv4/ip_forward) | ERRNO : %d | %s \n", __LINE__, errno, sys_errlist[errno]);
       #endif
       return;
    }
@@ -394,9 +392,6 @@ void Inet_RestoreForwarding(void)
    fclose(fd);
 }
 
-
-
-
 char *Inet_MacFromIP(unsigned long ip)
 {
    int sock;
@@ -417,7 +412,6 @@ char *Inet_MacFromIP(unsigned long ip)
    if ((sock = socket(AF_INET, SOCK_PACKET, 0)) == -1)
       Error_msg("ec_Inet_linux:%d socket() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
 
-
    if (ioctl(sock, SIOCGARP, (caddr_t)&ar) == -1)  // not in cache... try to find it...
    {
       u_char *buf;
@@ -492,4 +486,158 @@ char *Inet_MacFromIP(unsigned long ip)
 
 }
 
+// ARP ENTRY MANAGEMENT ---------------------------
+
+unsigned long SavedIP;
+unsigned char SavedMAC[6];
+
+void Inet_UnSetARPEntry(void)
+{
+    struct arpreq req;
+    int sockfd;
+    struct sockaddr_in *sin;
+
+#ifdef DEBUG
+   Debug_msg("Inet_UnSetARPEntry");
+#endif
+
+    sockfd = socket(AF_INET, SOCK_DGRAM, 0);
+
+    memset((char *) &req, 0, sizeof(req));
+    sin = (struct sockaddr_in *)&req.arp_pa;
+    sin->sin_family = AF_INET;
+    sin->sin_addr.s_addr = SavedIP;
+    req.arp_flags = ATF_PERM | ATF_COM;
+
+    memcpy(req.arp_ha.sa_data, SavedMAC, 6);
+    strcpy(req.arp_dev, Options.netiface);
+
+    ioctl(sockfd, SIOCDARP, &req);
+
+    close(sockfd);
+}
+
+
+int Inet_SetARPEntry(unsigned long IP, char MAC[6])
+{
+    struct arpreq req;
+    int sockfd;
+    struct sockaddr_in *sin;
+    int retval;
+
+#ifdef DEBUG
+   Debug_msg("Inet_SetARPEntry");
+#endif
+
+    sockfd = socket(AF_INET, SOCK_DGRAM, 0);
+
+    memset((char *) &req, 0, sizeof(req));
+    sin = (struct sockaddr_in *)&req.arp_pa;
+    sin->sin_family = AF_INET;
+    sin->sin_addr.s_addr = IP;
+    req.arp_flags = ATF_PERM | ATF_COM;
+
+    memcpy(req.arp_ha.sa_data, MAC, 6);
+    strcpy(req.arp_dev, Options.netiface);
+
+    retval = ioctl(sockfd, SIOCSARP, &req);
+
+    close(sockfd);
+
+    SavedIP=IP;
+    memcpy(SavedMAC, MAC, 6);
+    exit_func(Inet_UnSetARPEntry);
+
+    return retval;
+}
+
+// ROUTE MANAGEMENT ---------------------------
+
+struct rtentry
+{
+    unsigned long int rt_pad1;
+    struct sockaddr_in rt_dst;
+    struct sockaddr_in rt_gateway;
+    struct sockaddr_in rt_genmask;
+    unsigned short int rt_flags;
+    short int rt_pad2;
+    unsigned long int rt_pad3;
+    unsigned char rt_tos;
+    unsigned char rt_class;
+    short int rt_pad4;
+    short int rt_metric;
+    char *rt_dev;
+    unsigned long int rt_mtu;
+    unsigned long int rt_window;
+    unsigned short int rt_irtt;
+};
+
+void Inet_UnsetRoute(void)
+{
+    int skfd;
+    struct rtentry rt;
+
+#ifdef DEBUG
+   Debug_msg("Inet_UnsetRoute");
+#endif
+
+    skfd = socket(AF_INET, SOCK_DGRAM, 0);
+
+    memset((char *)&rt,0, sizeof(struct rtentry));
+
+    rt.rt_dst.sin_family=AF_INET;
+    rt.rt_dst.sin_addr.s_addr=inet_addr("1.0.0.1");
+    rt.rt_genmask.sin_family=AF_INET;
+    rt.rt_genmask.sin_addr.s_addr=inet_addr("255.255.255.255");
+    rt.rt_flags=5;
+    rt.rt_dev=Options.netiface;
+
+    ioctl(skfd, SIOCDELRT, &rt);
+
+    rt.rt_dst.sin_addr.s_addr=inet_addr("1.0.0.0");
+    rt.rt_gateway.sin_family=AF_INET;
+    rt.rt_gateway.sin_addr.s_addr=inet_addr("1.0.0.1");
+    rt.rt_genmask.sin_addr.s_addr=inet_addr("255.0.0.0");
+    rt.rt_flags=3;
+
+    ioctl(skfd, SIOCDELRT, &rt);
+
+    close(skfd);
+}
+
+void Inet_SetRoute(void)
+{
+    int skfd;
+    struct rtentry rt;
+
+#ifdef DEBUG
+   Debug_msg("Inet_SetRoute");
+#endif
+
+    skfd = socket(AF_INET, SOCK_DGRAM, 0);
+
+    memset((char *)&rt,0, sizeof(struct rtentry));
+
+    rt.rt_dst.sin_family=AF_INET;
+    rt.rt_dst.sin_addr.s_addr=inet_addr("1.0.0.1");
+    rt.rt_genmask.sin_family=AF_INET;
+    rt.rt_genmask.sin_addr.s_addr=inet_addr("255.255.255.255");
+    rt.rt_flags=5;
+    rt.rt_dev=Options.netiface;
+
+    ioctl(skfd, SIOCADDRT, &rt);
+
+    rt.rt_dst.sin_addr.s_addr=inet_addr("1.0.0.0");
+    rt.rt_gateway.sin_family=AF_INET;
+    rt.rt_gateway.sin_addr.s_addr=inet_addr("1.0.0.1");
+    rt.rt_genmask.sin_addr.s_addr=inet_addr("255.0.0.0");
+    rt.rt_flags=3;
+
+    ioctl(skfd, SIOCADDRT, &rt);
+
+    close(skfd);
+
+    exit_func(Inet_UnsetRoute);
+}
+
 /* EOF */
